﻿using System;
using System.Windows.Automation;
using System.Windows.Data;

namespace TriStateModeInDeep
{
    /// <summary>
    /// Bool2ToggleStateConverter
    /// </summary>
    public class BooleanToToggleStateConverter : IValueConverter
    {
        #region IValueConverter Members

        /// <summary>
        /// Converts a value.
        /// </summary>
        /// <param name="value">The value produced by the binding source.</param>
        /// <param name="targetType">The type of the binding target property.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        public object Convert( object value, Type targetType, object parameter, System.Globalization.CultureInfo culture )
        {
            if ( value is bool? )
            {
                var nullableBoolValue = ( bool? ) value;
                if ( nullableBoolValue.HasValue )
                    return nullableBoolValue.Value ? ToggleState.On : ToggleState.Off;
                return ToggleState.Indeterminate;
            }
            else if ( value is bool )
                return ( ( bool ) value ) ? ToggleState.On : ToggleState.Off;

            return ToggleState.Indeterminate;
        }
        /// <summary>
        /// Converts a value.
        /// </summary>
        /// <param name="value">The value that is produced by the binding target.</param>
        /// <param name="targetType">The type to convert to.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        public object ConvertBack( object value, Type targetType, object parameter, System.Globalization.CultureInfo culture )
        {
            if ( value is ToggleState )
            {
                switch ( ( ToggleState ) value )
                {
                    case ToggleState.On:
                        return true;
                    case ToggleState.Off:
                        return false;
                }
            }
            return null;
        }

        #endregion
    }
}
